@@ -1,8 +1,5 @@
-from __future__ import unicode_literals, print_function
-
 import warnings
 from datetime import datetime, timedelta
-import six
 from abc import ABCMeta, abstractmethod, abstractproperty
 from werkzeug.datastructures import CallbackDict
 import flask
@@ -21,11 +18,12 @@ oauth_before_login = _signals.signal("oauth-before-login")
 oauth_error = _signals.signal("oauth-error")
 
 
-class BaseOAuthConsumerBlueprint(six.with_metaclass(ABCMeta, flask.Blueprint)):
+class BaseOAuthConsumerBlueprint(flask.Blueprint, metaclass=ABCMeta):
     def __init__(
         self,
         name,
         import_name,
+        *,
         static_folder=None,
         static_url_path=None,
         template_folder=None,
@@ -36,6 +34,7 @@ class BaseOAuthConsumerBlueprint(six.with_metaclass(ABCMeta, flask.Blueprint)):
         login_url=None,
         authorized_url=None,
         storage=None,
+        rule_kwargs=None,
     ):
 
         bp_kwargs = dict(
@@ -49,22 +48,23 @@ class BaseOAuthConsumerBlueprint(six.with_metaclass(ABCMeta, flask.Blueprint)):
             url_defaults=url_defaults,
             root_path=root_path,
         )
-        # `root_path` didn't exist in 0.10, and will cause an error if it's
-        # passed in that version. Only pass `root_path` if it's set.
-        if bp_kwargs["root_path"] is None:
-            del bp_kwargs["root_path"]
         flask.Blueprint.__init__(self, **bp_kwargs)
 
         login_url = login_url or "/{bp.name}"
         authorized_url = authorized_url or "/{bp.name}/authorized"
+        rule_kwargs = rule_kwargs or {}
 
         self.add_url_rule(
-            rule=login_url.format(bp=self), endpoint="login", view_func=self.login
+            rule=login_url.format(bp=self),
+            endpoint="login",
+            view_func=self.login,
+            **rule_kwargs,
         )
         self.add_url_rule(
             rule=authorized_url.format(bp=self),
             endpoint="authorized",
             view_func=self.authorized,
+            **rule_kwargs,
         )
 
         if storage is None:
@@ -76,7 +76,13 @@ class BaseOAuthConsumerBlueprint(six.with_metaclass(ABCMeta, flask.Blueprint)):
 
         self.logged_in_funcs = []
         self.from_config = {}
-        invalidate_token = lambda d: invalidate_cached_property(self.session, "token")
+
+        def invalidate_token(d):
+            try:
+                invalidate_cached_property(self.session, "token")
+            except KeyError:
+                pass
+
         self.config = CallbackDict(on_update=invalidate_token)
         self.before_app_request(self.load_config)
 
@@ -148,12 +154,18 @@ class BaseOAuthConsumerBlueprint(six.with_metaclass(ABCMeta, flask.Blueprint)):
             expires_at = datetime.utcnow() + delta
             _token["expires_at"] = timestamp_from_datetime(expires_at)
         self.storage.set(self, _token)
-        invalidate_cached_property(self.session, "token")
+        try:
+            invalidate_cached_property(self.session, "token")
+        except KeyError:
+            pass
 
     @token.deleter
     def token(self):
         self.storage.delete(self)
-        invalidate_cached_property(self.session, "token")
+        try:
+            invalidate_cached_property(self.session, "token")
+        except KeyError:
+            pass
 
     @abstractproperty
     def session(self):
