@@ -1,13 +1,8 @@
-from __future__ import unicode_literals
-
 from flask_dance.consumer import OAuth2ConsumerBlueprint
 from functools import partial
 from flask.globals import LocalProxy, _lookup_app_object
 
-try:
-    from flask import _app_ctx_stack as stack
-except ImportError:
-    from flask import _request_ctx_stack as stack
+from flask import _app_ctx_stack as stack
 
 
 __maintainer__ = "David Baumgold <david@davidbaumgold.com>"
@@ -16,6 +11,7 @@ __maintainer__ = "David Baumgold <david@davidbaumgold.com>"
 def make_dropbox_blueprint(
     app_key=None,
     app_secret=None,
+    *,
     scope=None,
     offline=False,
     force_reapprove=False,
@@ -27,6 +23,7 @@ def make_dropbox_blueprint(
     authorized_url=None,
     session_class=None,
     storage=None,
+    rule_kwargs=None,
 ):
     """
     Make a blueprint for authenticating with Dropbox using OAuth 2. This requires
@@ -68,9 +65,11 @@ def make_dropbox_blueprint(
         storage: A token storage class, or an instance of a token storage
                 class, to use for this blueprint. Defaults to
                 :class:`~flask_dance.consumer.storage.session.SessionStorage`.
+        rule_kwargs (dict, optional): Additional arguments that should be passed when adding
+            the login and authorized routes. Defaults to ``None``.
 
     :rtype: :class:`~flask_dance.consumer.OAuth2ConsumerBlueprint`
-    :returns: A :ref:`blueprint <flask:blueprints>` to attach to your Flask app.
+    :returns: A :doc:`blueprint <flask:blueprints>` to attach to your Flask app.
     """
     authorization_url_params = {}
     if offline:
@@ -98,6 +97,7 @@ def make_dropbox_blueprint(
         authorization_url_params=authorization_url_params,
         session_class=session_class,
         storage=storage,
+        rule_kwargs=rule_kwargs,
     )
     dropbox_bp.from_config["client_id"] = "DROPBOX_OAUTH_CLIENT_ID"
     dropbox_bp.from_config["client_secret"] = "DROPBOX_OAUTH_CLIENT_SECRET"
