@@ -1,13 +1,8 @@
-from __future__ import unicode_literals
-
 from flask_dance.consumer import OAuth2ConsumerBlueprint
 from functools import partial
 from flask.globals import LocalProxy, _lookup_app_object
 
-try:
-    from flask import _app_ctx_stack as stack
-except ImportError:
-    from flask import _request_ctx_stack as stack
+from flask import _app_ctx_stack as stack
 
 
 __maintainer__ = "Matt Bachmann <bachmann.matt@gmail.com>"
@@ -16,6 +11,7 @@ __maintainer__ = "Matt Bachmann <bachmann.matt@gmail.com>"
 def make_facebook_blueprint(
     client_id=None,
     client_secret=None,
+    *,
     scope=None,
     redirect_url=None,
     redirect_to=None,
@@ -24,6 +20,7 @@ def make_facebook_blueprint(
     rerequest_declined_permissions=False,
     session_class=None,
     storage=None,
+    rule_kwargs=None,
 ):
     """
     Make a blueprint for authenticating with Facebook using OAuth 2. This requires
@@ -53,9 +50,11 @@ def make_facebook_blueprint(
         storage: A token storage class, or an instance of a token storage
                 class, to use for this blueprint. Defaults to
                 :class:`~flask_dance.consumer.storage.session.SessionStorage`.
+        rule_kwargs (dict, optional): Additional arguments that should be passed when adding
+            the login and authorized routes. Defaults to ``None``.
 
     :rtype: :class:`~flask_dance.consumer.OAuth2ConsumerBlueprint`
-    :returns: A :ref:`blueprint <flask:blueprints>` to attach to your Flask app.
+    :returns: A :doc:`blueprint <flask:blueprints>` to attach to your Flask app.
     """
     authorization_url_params = {}
     if rerequest_declined_permissions:
@@ -76,6 +75,7 @@ def make_facebook_blueprint(
         authorized_url=authorized_url,
         session_class=session_class,
         storage=storage,
+        rule_kwargs=rule_kwargs,
     )
     facebook_bp.from_config["client_id"] = "FACEBOOK_OAUTH_CLIENT_ID"
     facebook_bp.from_config["client_secret"] = "FACEBOOK_OAUTH_CLIENT_SECRET"
