@@ -1,13 +1,8 @@
-from __future__ import unicode_literals
-
 from flask_dance.consumer import OAuth1ConsumerBlueprint
 from functools import partial
 from flask.globals import LocalProxy, _lookup_app_object
 
-try:
-    from flask import _app_ctx_stack as stack
-except ImportError:
-    from flask import _request_ctx_stack as stack
+from flask import _app_ctx_stack as stack
 
 
 __maintainer__ = "David Baumgold <david@davidbaumgold.com>"
@@ -16,12 +11,14 @@ __maintainer__ = "David Baumgold <david@davidbaumgold.com>"
 def make_twitter_blueprint(
     api_key=None,
     api_secret=None,
+    *,
     redirect_url=None,
     redirect_to=None,
     login_url=None,
     authorized_url=None,
     session_class=None,
     storage=None,
+    rule_kwargs=None,
 ):
     """
     Make a blueprint for authenticating with Twitter using OAuth 1. This requires
@@ -48,9 +45,11 @@ def make_twitter_blueprint(
         storage: A token storage class, or an instance of a token storage
                 class, to use for this blueprint. Defaults to
                 :class:`~flask_dance.consumer.storage.session.SessionStorage`.
+        rule_kwargs (dict, optional): Additional arguments that should be passed when adding
+            the login and authorized routes. Defaults to ``None``.
 
     :rtype: :class:`~flask_dance.consumer.OAuth1ConsumerBlueprint`
-    :returns: A :ref:`blueprint <flask:blueprints>` to attach to your Flask app.
+    :returns: A :doc:`blueprint <flask:blueprints>` to attach to your Flask app.
     """
     twitter_bp = OAuth1ConsumerBlueprint(
         "twitter",
@@ -67,6 +66,7 @@ def make_twitter_blueprint(
         authorized_url=authorized_url,
         session_class=session_class,
         storage=storage,
+        rule_kwargs=rule_kwargs,
     )
     twitter_bp.from_config["client_key"] = "TWITTER_OAUTH_CLIENT_KEY"
     twitter_bp.from_config["client_secret"] = "TWITTER_OAUTH_CLIENT_SECRET"
